<?php
/**
 * Theme Functions.
 */

/* Theme Setup */
if ( ! function_exists( 'advance_marketing_agency_setup' ) ) :

function advance_marketing_agency_setup() {

	$GLOBALS['content_width'] = apply_filters( 'advance_marketing_agency_content_width', 640 );

	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'align-wide' );
	add_theme_support( 'wp-block-styles' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );

	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );

	add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );

	add_theme_support('responsive-embeds');
	/*
	 * This theme styles the visual editor to resemble the theme style,
	 * specifically font, colors, icons, and column width.
	 */
	add_editor_style( array( 'css/editor-style.css', multi_advance_font_url() ) );
}
endif;
add_action( 'after_setup_theme', 'advance_marketing_agency_setup' );

/* Theme Widgets Setup */
function advance_marketing_agency_widgets_init() {

	register_sidebar( array(
		'name'          => __( 'Footer Nav 1', 'advance-marketing-agency' ),
		'id'            => 'footer-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s py-3">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title pb-2 mb-3">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Nav 2', 'advance-marketing-agency' ),
		'id'            => 'footer-2',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s py-3">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title pb-2 mb-3">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Nav 3', 'advance-marketing-agency' ),
		'id'            => 'footer-3',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s py-3">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title pb-2 mb-3">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer Nav 4', 'advance-marketing-agency' ),
		'id'            => 'footer-4',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s py-3">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title pb-2 mb-3">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'advance_marketing_agency_widgets_init' );

function advance_marketing_agency_customize_register() {     
	global $wp_customize;

	$wp_customize->remove_setting( 'multi_advance_footer_widget_areas' );
	$wp_customize->remove_control( 'multi_advance_footer_widget_areas' );

	$wp_customize->remove_setting( 'multi_advance_display_topbar' );
	$wp_customize->remove_control( 'multi_advance_display_topbar' );	

	$wp_customize->remove_setting( 'multi_advance_header_premium_info' );
	$wp_customize->remove_control( 'multi_advance_header_premium_info' );

	$wp_customize->remove_setting( 'multi_advance_footer_premium_info' );
	$wp_customize->remove_control( 'multi_advance_footer_premium_info' );
} 

// Customizer Section
function advance_marketing_agency_customizer ( $wp_customize ) {

	$wp_customize->add_setting('advance_marketing_agency_header_premium_info',array(
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('advance_marketing_agency_header_premium_info',array(
		'priority' => 12,
		'type'=> 'hidden',
		'description' => "<p>For more settings and features, please explore our premium theme.</p><a target='_blank' href='". esc_url('https://www.themeshopy.com/themes/marketing-agent-wordpress-theme/') ." '>Upgrade to Pro</a>",
		'section'=> 'multi_advance_header'
	));

	$wp_customize->add_setting('advance_marketing_agency_footer_premium_info',array(
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('advance_marketing_agency_footer_premium_info',array(
		'priority' => 12,
		'type'=> 'hidden',
		'description' => "<p>For more settings and features, please explore our premium theme.</p><a target='_blank' href='". esc_url('https://www.themeshopy.com/themes/marketing-agent-wordpress-theme/') ." '>Upgrade to Pro</a>",
		'section'=> 'multi_advance_footer_section'
	));

}
add_action( 'customize_register', 'advance_marketing_agency_customizer' );

/*------------------------------section-pro.php part----------------------------------------*/
require_once( ABSPATH . WPINC . '/class-wp-customize-section.php' );

class Advance_Marketing_Agency_Customize_Section_Pro extends WP_Customize_Section {

	/**
	 * Outputs the Underscore.js template.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	protected function render_template() { ?>

		<li id="accordion-section-{{ data.id }}" class="accordion-section control-section control-section-{{ data.type }} cannot-expand">
			<h3 class="accordion-section-title">
				{{ data.title }}

				<# if ( data.pro_text && data.pro_url ) { #>
					<a href="{{ data.pro_url }}" class="button button-secondary alignright" target="_blank">{{ data.pro_text }}</a>
				<# } #>
			</h3>
		</li>
	<?php }
}

/*---------------customizer.php part--------------------------*/
/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Advance_Marketing_Agency_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Register custom section types.
		$manager->register_section_type( 'Advance_Marketing_Agency_Customize_Section_Pro' );

	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */

	public function enqueue_control_scripts() {
		wp_enqueue_style( 'advance_marketing_agency-customize-controls', get_stylesheet_directory_uri() . '/css/customize-controls-child.css' );
	}
}

// Doing this customizer thang!
Advance_Marketing_Agency_Customize::get_instance();


define('ADVANCE_MARKETING_AGENCY_CREDIT',__('https://www.themeshopy.com/themes/free-marketing-agency-wordpress-theme/', 'advance-marketing-agency'));

if (!function_exists('advance_marketing_agency_credit')) {
	function advance_marketing_agency_credit() {
		echo "<a href=".esc_url(ADVANCE_MARKETING_AGENCY_CREDIT)." target='_blank''>".esc_html__('Marketing Agency WordPress Theme', 'advance-marketing-agency')."</a>";
	}
}

add_action( 'customize_register', 'advance_marketing_agency_customize_register', 11 );

add_action( 'wp_enqueue_scripts', 'advance_marketing_agency_enqueue_styles' );
function advance_marketing_agency_enqueue_styles() {
	wp_enqueue_style('bootstrap-style', get_template_directory_uri().'/css/bootstrap.css');
	$parent_style = 'multi-advance-basic-style'; // Style handle of parent theme.
	wp_enqueue_style( $parent_style, get_template_directory_uri() . '/style.css' );
	wp_enqueue_style( 'advance-marketing-agency-style', get_stylesheet_uri(), array( $parent_style ) );
	require get_parent_theme_file_path( '/inc/ts-color-pallete.php' );
	wp_add_inline_style( 'advance-marketing-agency-style',$multi_advance_custom_css );
	require get_theme_file_path( '/ts-color-pallete.php' );
	wp_add_inline_style( 'advance-marketing-agency-style',$multi_advance_custom_css );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}

if ( ! defined( 'MULTI_ADVANCE_PRO_THEME_LINK' ) ) {
	define( 'MULTI_ADVANCE_PRO_THEME_LINK',__('https://www.themeshopy.com/themes/marketing-agent-wordpress-theme/','advance-marketing-agency') );
}

if ( ! defined( 'MULTI_ADVANCE_PRO_THEME_TEXT' ) ) {
	define( 'MULTI_ADVANCE_PRO_THEME_TEXT', __('Advance Marketing Pro','advance-marketing-agency') );
}